new_http_client

Function new_http_client 

pub fn new_http_client(
    options: Option<HttpClientOptions>,
) -> Arc<dyn HttpClient> ⓘ
Create a new HttpClient.

Arguments

  • options - Optional configuration for the Client. Automatic decompression is enabled if reqwest_gzip or reqwest_deflate are enabled. Client libraries can disable this without impacting other client libraries by disabling it when calling this function.