pub struct ClientOptions {
pub per_call_policies: Vec<Arc<dyn Policy>>,
pub per_try_policies: Vec<Arc<dyn Policy>>,
pub retry: RetryOptions,
pub transport: Option<Transport>,
pub user_agent: UserAgentOptions,
pub instrumentation: InstrumentationOptions,
pub logging: LoggingOptions,
pub cloud: Option<Arc<CloudConfiguration>>,
}Expand description
Client options allow customization of general client policies, retry options, and more.
Fields
per_call_policies: Vec<Arc<dyn Policy>>Policies called per call.
per_try_policies: Vec<Arc<dyn Policy>>Policies called per try.
retry: RetryOptionsRetry options.
transport: Option<Transport>Transport options.
user_agent: UserAgentOptionsUser-Agent telemetry options.
instrumentation: InstrumentationOptionsOptions for request instrumentation, such as distributed tracing.
If not specified, defaults to no instrumentation.
logging: LoggingOptionsLogging options
Specifies which headers and query parameters should be logged. All headers and query parameters not in the allow list will be redacted.
cloud: Option<Arc<CloudConfiguration>>Cloud configuration for the client. If None, the client will default to Azure Public Cloud.