Context

Struct Context 

pub struct Context<'a> { /* private fields */ }
Pipeline execution context.

Do not store Personally-Identifiable Information (PII) in a Context. It could easily leak in logs or traces.

Implementations

Source

impl<'a> Context<'a>

pub fn new() -> Context<'a>

Creates a new, empty Context.

pub fn with_context<'b>(context: &'a Context<'_>) -> Context<'b>
where 'a: 'b,

👎Deprecated since 0.7.0:

use to_borrowed() instead

Returns a new Context that borrows the type map of the given context.

Once you Context::insert entities the type map is copied.

pub fn with_value<E>(self, entity: E) -> Context<'a>
where E: Send + Sync + 'static,

Inserts or replaces an entity in the type map and returns Self to allow chaining.

Examples
use typespec_client_core::http::Context;

let context = Context::new()
    .with_value(1)
    .with_value("test");
assert_eq!(context.value(), Some(&"test"));
pub fn insert<E>(&mut self, entity: E) -> Option<Arc<E>>
where E: Send + Sync + 'static,

Inserts or replaces an entity in the type map. If an entity with the same type was displaced by the insert, it will be returned to the caller.

Examples
use typespec_client_core::http::Context;
use std::sync::Arc;

let mut context = Context::new().with_value("a".to_string());
assert_eq!(context.insert("b".to_string()), Some(Arc::new("a".to_string())));
assert_eq!(context.value(), Some(&"b".to_string()));
pub fn value<E>(&self) -> Option<&E>
where E: Send + Sync + 'static,

Returns a reference of the entity of the specified type signature, if it exists.

If there is no entity with the specific type signature, None is returned instead.

pub fn is_empty(&self) -> bool

Returns true if the type map is empty; otherwise, false.

pub fn into_owned(self) -> Context<'static>

Transforms this Context into a new Context that owns the underlying data, cloning it if necessary.

If this Context already owns the underlying data, that data is moved into the new Context as-is. If this Context is borrowing it’s underlying data, that data is cloned and returned as a new Context.

pub fn to_owned(&self) -> Context<'static>

Transforms this Context into a new Context that owns the underlying data, cloning it if necessary.

Clone the underlying data in the Context and return it in a new owned Context.

pub fn to_borrowed<'b>(&'a self) -> Context<'b>
where 'a: 'b,

Returns a new Context that borrows the type map of the given context.

Once you Context::insert entities the type map is copied.