LoggingOptions

Struct LoggingOptions 

pub struct LoggingOptions {
    pub additional_allowed_header_names: Vec<Cow<'static, str>>,
    pub additional_allowed_query_params: Vec<Cow<'static, str>>,
}
Controls what HTTP headers and query parameters are logged by default.

Headers and query parameters not in the allow list will be redacted.

This list is added to the default allow list of headers and query parameters.

Fields

additional_allowed_header_names: Vec<Cow<'static, str>>

The allowed header names to be logged.

additional_allowed_query_params: Vec<Cow<'static, str>>

The allowed query parameters to be logged.