pub struct NoFormat;Expand description
A Format indicating that the response has no structured format.
This includes responses that return raw data and that don’t return a response body.
This format supports deserializing response bodies to:
ResponseBody- The raw response body, without any deserialization.