pub struct PipelineOptions {
pub retry_headers: RetryHeaders,
pub retry_status_codes: Vec<StatusCode>,
}Expand description
Options for constructing a Pipeline
Fields
retry_headers: RetryHeadersThe set of headers which should be considered when determining the interval to wait for retry attempts. This field doesn’t apply to custom retry policies.
retry_status_codes: Vec<StatusCode>The status codes that should trigger retries. This field doesn’t apply to custom retry policies.
When empty, the default retry status codes are used as
described by crate::http::policies::RetryPolicy::retry_status_codes.