AppendToUrlQuery

Trait AppendToUrlQuery 

pub trait AppendToUrlQuery {
    // Required method
    fn append_to_url_query(&self, url: &mut Url);
}
Add a new query pair into the target Url’s query string.

Required Methods

fn append_to_url_query(&self, url: &mut Url)

Append the query pair represented by self to the given url.

Arguments
  • url - The mutable reference to the Url to which the query pair will be appended.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> AppendToUrlQuery for &T

Source

fn append_to_url_query(&self, url: &mut Url)

Source

impl<T> AppendToUrlQuery for Option<T>

Source

fn append_to_url_query(&self, url: &mut Url)

Implementors