pub fn new_http_client(
options: Option<HttpClientOptions>,
) -> Arc<dyn HttpClient> ⓘExpand description
Create a new HttpClient.
Arguments
options- Optional configuration for theClient. Automatic decompression is enabled ifreqwest_gziporreqwest_deflateare enabled. Client libraries can disable this without impacting other client libraries by disabling it when calling this function.