pub trait AppendToUrlQuery {
// Required method
fn append_to_url_query(&self, url: &mut Url);
}Expand description
Add a new query pair into the target Url’s query string.
Required Methods
Sourcefn append_to_url_query(&self, url: &mut Url)
fn append_to_url_query(&self, url: &mut Url)
Append the query pair represented by self to the given url.
Arguments
url- The mutable reference to theUrlto which the query pair will be appended.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".